#
# spec file for package openexr
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openexr
Version:        1.7.1
Release:        0
Summary:        Utilities for work with HDR images in OpenEXR format
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
Url:            http://www.openexr.com/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fltk-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  ilmbase-devel
# bug437293
%ifarch ppc64
Obsoletes:      OpenEXR-64bit
%endif
#
Obsoletes:      OpenEXR <= 1.6.1
Provides:       OpenEXR = %{version}
Source0:        %{name}-%version.tar.gz
Source1:        baselibs.conf
Patch0:         openexr-suse-docdir.patch
# disable broken tests
Patch1:         openexr-disable-tests.patch

%description
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications. This package
contains a set of utilities to work with this format.

* exrheader, a utility for dumping header information
* exrstdattr, a utility for modifying OpenEXR standard attributes
* exrmaketiled, for generating tiled and rip/mipmapped images
* exrenvmap, for creating OpenEXR environment maps
* exrmakepreview, for creating preview images for OpenEXR files
* exr2aces, converter to ACES format
* exrmultiview, combine two or more images into one multi-view

%package -n libIlmImf7
Summary:        Library to Handle EXR Pictures in 16-Bit Floating-Point Format
Group:          Development/Libraries/C and C++
# provide also the most expected symbol
Provides:       libopenexr7 = %{version}

%description -n libIlmImf7
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains libIlmImf.so.6

%post -n libIlmImf7 -p /sbin/ldconfig

%postun -n libIlmImf7 -p /sbin/ldconfig

%files -n libIlmImf7
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libIlmImf.so.*

%package devel
Summary:        Library to Handle EXR Pictures (16-bit floating-point format)
Group:          Development/Libraries/C and C++
Obsoletes:      OpenEXR-devel <= 1.6.1
Provides:       OpenEXR-devel = %{version}
Obsoletes:      libopenexr-devel <= 1.7.0
Provides:       libopenexr-devel = %{version}
Requires:       libilmbase-devel
Requires:       libopenexr7 = %{version}
Requires:       pkg-config
Requires:       zlib-devel

%description devel
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains header files.

%package doc
Summary:        Library to Handle EXR Pictures in 16-Bit Floating-Point Format
Group:          Development/Libraries/C and C++
Obsoletes:      OpenEXR-doc <= 1.6.1
Provides:       OpenEXR-doc = %{version}

%description doc
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains a documentation

%prep
%setup -q
%patch0 -p0
%patch1 -p1

# remove a non-linux file
%{__rm} README.win32 README.OSX

%build
#autoreconf --force --install --include=config
#
export PTHREAD_LIBS="-lpthread"
%{configure} \
   --disable-static \
   --with-pic \
   --enable-large-stack \
   --enable-imfexamples \
   --enable-imfuzztest
%{__make} %{?_smp_mflags}

%install
%{makeinstall}
%{__rm} -f %{buildroot}%{_libdir}/*.la

%check
#XXX: it seems running tests in BS is not very reliable, so
#     so let disable it
# % {__make} check

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING LICENSE NEWS README*
%{_bindir}/exrenvmap
%{_bindir}/exrheader
%{_bindir}/exrmakepreview
%{_bindir}/exrmaketiled
%{_bindir}/exrstdattr
%{_bindir}/exr2aces
%{_bindir}/exrmultiview

%files devel
%defattr(-,root,root)
%{_includedir}/OpenEXR
%{_libdir}/libIlmImf.so
%{_libdir}/pkgconfig/OpenEXR.pc
%{_datadir}/aclocal/openexr.m4

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}-%{version}

%changelog
